package com.weilab.biology.controller;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.weilab.biology.core.data.enums.JobStatusEnum;
import com.weilab.biology.core.data.vo.result.CommonError;
import com.weilab.biology.core.data.vo.result.Result;
import com.weilab.biology.core.data.vo.result.error.JobError;
import com.weilab.biology.core.validation.EnumValidation;
import com.weilab.biology.service.JobService;
import com.weilab.biology.util.FileUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;


@RestController
@RequestMapping("job")
public class JobController {

    @Autowired
    private JobService jobService;

    @Value("${biology.request-path}")
    private String requestPath;

    @PostMapping("/submit")
    public Result submit(@RequestParam(required = false) String dataStr,
                         @RequestParam(required = false) MultipartFile dataFile,
                         @RequestParam String param,
                         @RequestParam String mail,
                         @RequestParam(defaultValue = "0") Integer type,
                         @RequestParam(required = false) MultipartFile file1,
                         @RequestParam(required = false) MultipartFile file2,
                         @RequestParam(required = false) MultipartFile file3,
                         @RequestParam(required = false) MultipartFile file4,
                         @RequestParam(required = false) MultipartFile file5,
                         @RequestParam(required = false) MultipartFile file6,
                         @RequestParam(required = false) MultipartFile file7,
                         @RequestParam(required = false) MultipartFile file8,
                         @RequestParam(required = false) MultipartFile file9,
                         @RequestParam(required = false) MultipartFile file10,
                         @RequestParam(required = false) MultipartFile file11,
                         @RequestParam(required = false) MultipartFile file12,
                         @RequestParam(required = false) MultipartFile file13,
                         @RequestParam(required = false) MultipartFile file14,
                         @RequestParam(required = false) MultipartFile file15,
                         @RequestParam(required = false) MultipartFile file16,
                         @RequestParam(required = false) MultipartFile file17,
                         @RequestParam(required = false) MultipartFile file18,
                         @RequestParam(required = false) MultipartFile file19,
                         @RequestParam(required = false) MultipartFile file20) {
        if (dataFile == null && StringUtils.isBlank(dataStr))
            return Result.getResult(JobError.PARAM_CAN_NOT_BE_EMPTY);

        JSONObject obj = null;
        try {
            obj = JSON.parseObject(param);
        } catch (Exception e) {
            return Result.getResult(CommonError.PARAM_WRONG);
        }

        BufferedInputStream dataStream = null;
        if (dataFile != null) {
            dataStream = FileUtil.getInputStream(FileUtils.multipartToFile(dataFile));
        }

        try {
            List<MultipartFile> files = Arrays.asList(file1, file2, file3, file4, file5,
                    file6, file7, file8, file9, file10, file11, file12, file13, file14, file15,
                    file16, file17, file18, file19, file20);
            for (MultipartFile file : files) {
                if (file != null) {
                    String filePath = requestPath + FileUtil.FILE_SEPARATOR + "file" + FileUtil.FILE_SEPARATOR + IdUtil.fastUUID() + "." + FileUtil.extName(file.getOriginalFilename());
                    FileUtil.writeFromStream(file.getInputStream(), filePath);
                    obj.put(file.getName(), filePath);
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
            return Result.getResult(JobError.FILE_READ_FAIL);
        }

        return jobService.submit(dataStr, dataStream, obj, mail, type);
    }

    @PostMapping("/status/update")
    public Result updateJobStatus(@RequestParam Integer jobId,
                                  @EnumValidation(clazz = JobStatusEnum.class, message = "没有此状态")
                                  @RequestParam Integer status,
                                  @RequestParam(required = false) String result) {
        if (status.equals(JobStatusEnum.WAIT.getKey()))
            return Result.getResult(CommonError.PARAM_WRONG);
        if (status.equals(JobStatusEnum.SUCCESS.getKey())) {
            if (StringUtils.isBlank(result))
                return Result.getResult(CommonError.PARAM_WRONG);
            try {
                JSON.parseObject(result);
            } catch (Exception e) {
                return Result.getResult(CommonError.PARAM_WRONG);
            }
        }
        return jobService.updateJobStatus(jobId, JobStatusEnum.getEnumByKey(status), result);
    }

    @GetMapping("/info/{jobId}")
    public Result getJobInfo(@PathVariable Integer jobId) {
        return jobService.getJobInfo(jobId);
    }

    @GetMapping("/list")
    public Result getJobList(@RequestParam(required = false) Integer type) {
        return jobService.getJobList(type);
    }
}
